pub struct ChatTemplateValue(pub Either<String, Vec<HashMap<String, String>>>);Expand description
Support older tool use patterns where the tool use template was separate from the default/chat template.
Modern patterns use a single template with a tool_use key, e.g.
{%- if tools is not none and tool_choice is not none %}Tuple Fields
0: Either<String, Vec<HashMap<String, String>>>Trait Implementations
Sourceimpl Debug for ChatTemplateValue
impl Debug for ChatTemplateValue
Sourceimpl<'de> Deserialize<'de> for ChatTemplateValue
impl<'de> Deserialize<'de> for ChatTemplateValue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more